/*
 * Copyright (c) 2023-2024.
 * Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum;

import java.time.Duration;
import java.time.temporal.ChronoUnit;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.web.client.RestTemplateBuilder;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.client.RestClient;
import org.springframework.web.client.RestTemplate;

@Configuration
public class WebConfiguration {
	public static final String INFO_MANAGER_REST_CLIENT = "infomanagerRestClient";
	public static final String NACHRICHT_REST_CLIENT = "nachrichtRestClient";
	public static final String X_OZG_CLIENT = "X-OZG-CLIENT";
	public static final String X_GRPC_ADDRESS = "X-Grpc-Address";
	public static final String ANTRAGSRAUM = "antragsraum";

	@Value("${ozgcloud.antragsraum.nachricht-proxy.base-url}")
	private String nachrichtProxyBaseUrl;
	@Value("${ozgcloud.antragsraum.infomanager-proxy.base-url}")
	private String infomanagerProxyBaseUrl;
	@Value("${clamav.connection.timeoutInS:15}")
	private int httpConnectionTimeoutInS;
	@Value("${clamav.read.timeoutInS:60}")
	private int httpReadTimeoutInS;

	@Bean
	public RestTemplate restTemplate(RestTemplateBuilder builder) {
		return builder.setReadTimeout(Duration.of(httpReadTimeoutInS, ChronoUnit.SECONDS))
		  .setConnectTimeout(Duration.of(httpConnectionTimeoutInS, ChronoUnit.SECONDS)).build();
	}

	@Bean(name = NACHRICHT_REST_CLIENT)
	public RestClient nachrichtRestClient() {
		return RestClient.builder()
		  .baseUrl(nachrichtProxyBaseUrl)
		  .defaultHeader(X_OZG_CLIENT, ANTRAGSRAUM)
		  .build();
	}

	@Bean(name = INFO_MANAGER_REST_CLIENT)
	public RestClient infomanagerRestClient() {
		return RestClient.builder()
		  .baseUrl(infomanagerProxyBaseUrl)
		  .defaultHeader(X_OZG_CLIENT, ANTRAGSRAUM)
		  .build();
	}
}